@@ -129,7 +129,7 @@ class ParseOptions(object):
         self.allow_null = allow_null
     
     def __del__(self):
-        if self._po is not None:
+        if self._po is not None and clg is not None:
             clg.parse_options_delete(self._po)
             self._po = None
 
@@ -329,7 +329,7 @@ class Dictionary(object):
         self._dict = clg.dictionary_create_lang(lang)
     
     def __del__(self):
-        if self._dict is not None:
+        if self._dict is not None and clg is not None:
             clg.dictionary_delete(self._dict)
             self._dict = None
             
